@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: json
 version: 0.9.1
-id: json-0.9.1-dbf392f6a0c16540f58dcd27de38198f
-key: json_Cbo8lbc326q82NwJTky9zy
+id: json-0.9.1-cd200e0fee92b59351aaf6bea84dc422
+key: json_8cdgJ72MNMwHHURVtzSy3c
 license: BSD3
 copyright: (c) 2007-2009 Galois Inc.
 maintainer: Iavor S. Diatchki (iavor.diatchki@gmail.com)
@@ -27,7 +27,7 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/json-0.9.1
 library-dirs: /usr/lib/ghc-7.10.3/site-local/json-0.9.1
 data-dir: /usr/share/arm-linux-ghc-7.10.3/json-0.9.1
-hs-libraries: HSjson-0.9.1-Cbo8lbc326q82NwJTky9zy
+hs-libraries: HSjson-0.9.1-8cdgJ72MNMwHHURVtzSy3c
 depends:
     array-0.5.1.0-a4b4f31b03b7779670557ea46745a386
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
@@ -36,7 +36,7 @@ depends:
     mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
     pretty-1.1.2.0-b06321e1e395640194b358a5374c465f
     syb-0.6-56a5944f55f7a9d47e7b770375c0e1ae
-    text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
+    text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
 haddock-interfaces: /usr/share/doc/haskell-json/html/json.haddock
 haddock-html: /usr/share/doc/haskell-json/html
 ' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
